DOH complex inheritance test

# AccordionContainer Tests textDir="rtl" - defined in body tag.

## Accordion from markup:

This Pane ovverrides the body defined textDir="rtl" to textDir="ltr". See some examples:

This Pane inherits its textDir from the dijit.layout.BorderContainer, and now textDir="auto". See some examples:

Here's a BorderContainer: textDir= contextual

Left Pane: Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt.
Right Pane: לורם איפסום דולור סיט אמט, קונסקטורר אדיפיסינג אלית מוסן מנת.

And a TabContainer:

jhkjkh.
מבחן. Test.